pub struct LookAhead<'t> { /* private fields */ }Expand description
A mapped StringIter that yields longer &strs by looking ahead.
Implementations
Methods from Deref<Target = StringIter<'t>>
Sourcepub fn try_next_slice<P: Pattern>(
&mut self,
pat: P,
) -> Result<Option<&'t str>, P::Err>
pub fn try_next_slice<P: Pattern>( &mut self, pat: P, ) -> Result<Option<&'t str>, P::Err>
Gets a slice out of a StringIter using a fallible pattern.
If Err is Never, you can use
the infallible version instead.
The iterator will not be changed if the match fails.
Pattern
Pattern Configuration
see SetSep
Sourcepub fn try_next_slice_back<P: Pattern>(
&mut self,
pat: P,
) -> Result<Option<&'t str>, P::Err>
pub fn try_next_slice_back<P: Pattern>( &mut self, pat: P, ) -> Result<Option<&'t str>, P::Err>
Gets a slice from a StringIter in reverse, using a fallible pattern.
If Err is Never, you can use
the infallible version instead.
The iterator will not be changed if the match fails.
See try_next_slice
Sourcepub fn next_slice<P: Pattern<Err = Never>>(&mut self, pat: P) -> Option<&'t str>
pub fn next_slice<P: Pattern<Err = Never>>(&mut self, pat: P) -> Option<&'t str>
Gets a slice from a StringIter, using a non-fallible pattern.
See try_next_slice
Sourcepub fn next_slice_back<P: Pattern<Err = Never>>(
&mut self,
pat: P,
) -> Option<&'t str>
pub fn next_slice_back<P: Pattern<Err = Never>>( &mut self, pat: P, ) -> Option<&'t str>
Gets a slice from a StringIter in reverse, using a non-fallible pattern.
See try_next_slice
Sourcepub fn next_char_back(&mut self) -> Option<(char, &'t str)>
pub fn next_char_back(&mut self) -> Option<(char, &'t str)>
Sourcepub fn trim_by(&mut self, f: impl Pattern<Err = Never> + Clone)
pub fn trim_by(&mut self, f: impl Pattern<Err = Never> + Clone)
Removes leading and trailing chars that matches a Pattern from the StringIter.
Sourcepub fn trim_start_by(&mut self, f: impl Pattern<Err = Never>)
pub fn trim_start_by(&mut self, f: impl Pattern<Err = Never>)
Removes leading chars that matches a Pattern from the StringIter.
Sourcepub fn trim_end_by(&mut self, f: impl Pattern<Err = Never>)
pub fn trim_end_by(&mut self, f: impl Pattern<Err = Never>)
Removes trailing chars that matches a Pattern from the StringIter.
Sourcepub fn as_str(&self) -> &'t str
pub fn as_str(&self) -> &'t str
Returns the underlying str of this StringIter
Sourcepub fn as_bytes(&self) -> &'t [u8]
pub fn as_bytes(&self) -> &'t [u8]
Returns the underlying [u8] of this StringIter
Sourcepub fn startswith(&self, s: &str) -> bool
pub fn startswith(&self, s: &str) -> bool
Sourcepub fn trim(&mut self)
pub fn trim(&mut self)
Removes leading and trailing whitespaces from this StringIter
Sourcepub fn trim_start(&mut self)
pub fn trim_start(&mut self)
Removes leading whitespaces from this StringIter
Sourcepub fn trim_end(&mut self)
pub fn trim_end(&mut self)
Removes trailing whitespaces from this StringIter
Sourcepub fn skip_front(&mut self, n: usize) -> bool
pub fn skip_front(&mut self, n: usize) -> bool
Skip n leading chars from this StringIter,
returns true if the string is empty afterwards.