Pattern

Trait Pattern 

pub trait Pattern {
    type Err: Debug;

    // Required method
    fn matches(&mut self, c: char, s: &str) -> Result<bool, Self::Err>;

    // Provided methods
    fn len(&self) -> NonZeroUsize { ... }
    fn sep(&self) -> Sep { ... }
}
A pattern for use in slice, split and trim functions.

Required Associated Types

Required Methods

fn matches(&mut self, c: char, s: &str) -> Result<bool, Self::Err>

Try matching a char in a pattern

Arguments
  • c - The current char, guaranteed to be the first char in s
  • s - The current &str, a substring of some length after c

In slice or split: match until the first true result

In trim_by: match until the first false result

len() is a suggestion for s.len(). However s is not guaranteed to have the same length as self.len(), since joining multiple patterns can increase s.len(), and corner cases will decrease s.len().

Provided Methods

fn len(&self) -> NonZeroUsize

Determines how many chars to look ahead, default 1.

The iterator will not stop prematurely because of look-ahead.

fn sep(&self) -> Sep

Determines what to do with the matched char on separation.

See also sep_with